==> moodle_1.3.1.orig.tar.gz: moodle/lang/sk/quiz.php <==
<?PHP // $Id: quiz.php,v 1.4 2003/09/10 12:24:02 moodler Exp $ Radik Kalakay - 2003-09-05 12:00 ver 1.1.a
      // quiz.php - created with Moodle 1.1 (2003082800)


$string['acceptederror'] = "Akceptovan chyba";
$string['addingquestions'] = "Toto je &#269;as&#357; strnky, kde si vediete databzu va&#353;ich otzok. Aby bolo otzky mo&#382;n udr&#382;a&#357; usporiadan a aby mohli by&#357; pou&#382;it v &#318;ubovo&#318;nom teste vo va&#353;om kurze, alebo dokonca aj inmi kurzami, ak sa rozhodnete publikova&#357; ich,s ulo&#382;en v kategrich.<br /><br />Ke&#271; vyberiete alebo vytvorte kategriu otzok, budete mc&#357; tvori&#357; alebo meni&#357; otzky. M&#382;ete vybra&#357; ktorko&#318;vek z tchto otzok a prida&#357; ju do v&#353;ho testu na ostatnch &#269;astiach tejto strnky.";
$string['addquestions'] = "Prida otzky";
$string['addquestionstoquiz'] = "Prida otzky do testu";
$string['addselectedtoquiz'] = "Vybran prida do testu";
$string['allowreview'] = "Povoli prehad";
$string['alreadysubmitted'] = "Je pravdepodobn e u ste predloili tento pokus";
$string['alwaysavailable'] = "Vdy dostupn";
$string['answer'] = "Odpove";
$string['answerhowmany'] = "Jedna, alebo viacero odpoved?";
$string['answersingleno'] = "Povolen viacero odpoved";
$string['answersingleyes'] = "Iba jedna odpove";
$string['answerswithacceptederrormarginmustbenumeric'] = "Odpovede s akceptovanmi chybami musia by slovan";
$string['attempt'] = "Pokus \$a";
$string['attemptfirst'] = "Prv pokus";
$string['attemptlast'] = "Posledn pokus";
$string['attemptquiznow'] = "Poksi sa urobi test teraz";
$string['attempts'] = "Pokusy";
$string['attemptsallowed'] = "Povolen poet pokusov";
$string['attemptsunlimited'] = "Neobmedzen pokusy";
$string['backtoquiz'] = "Sp na zapisovanie testu";
$string['bestgrade'] = "Najlepia znmka";
$string['blackboard'] = "ierna tabua";
$string['caseno'] = "Nie, vek a mal psmen nie s dleit";
$string['casesensitive'] = "Citlivos na vek a mal psmen";
$string['caseyes'] = "no, vek a mal psmen musia sedie";
$string['categories'] = "Kategrie";
$string['category'] = "Kategria";
$string['categoryinfo'] = "Informcie o kategrii";
$string['categorymove'] = "Kategria '\$a->name' obsahuje \$a->count otzok.  vyberte si prosm in kategriu, do ktorej ich prenesiete.";
$string['categorymoveto'] = "Preneste ich do tejto kategrie";
$string['choice'] = "Monos";
$string['choices'] = "Dostupn monosti";
$string['correctanswer'] = "Sprvna odpove";
$string['correctanswers'] = "Sprvne odpovede";
$string['countdown'] = "Odpotavanie";
$string['countdownfinished'] = "Test sa uzatvra, teraz moete zasiela svoje odpovede. ";
$string['countdowntenminutes'] = "Test sa uzavrie o 10 mint.";
$string['createmultiple'] = "Vytvori viacero otzok";
$string['createnewquestion'] = "Vytvori nov otzku";
$string['custom'] = "Uvatesk formt";
$string['daysavailable'] = "Dostupn dni";
$string['default'] = "Vchodiskov nastavenie";
$string['defaultgrade'] = "Prednastaven hodnota znmky";
$string['defaultinfo'] = "Nastaven kategria pre otzky.";
$string['deletequestioncheck'] = "Ste si plne ist, e chcete vymaza '\$a'?";
$string['description'] = "Opis";
$string['eachattemptbuildsonthelast'] = "Kad pokus je posaven na minulom";
$string['editcategories'] = "Upravi kategrie";
$string['editingdescription'] = "Upravi popis";
$string['editingmatch'] = "Editova zodpovedajcu otzku";
$string['editingmultianswer'] = "Upravi test s monosou vberu odpoved";
$string['editingmultichoice'] = "Zapisovanie otzky s viacermi monosami vberu";
$string['editingnumerical'] = "Upravi slovan otzky";
$string['editingquestion'] = "Zapisovanie otzky";
$string['editingquiz'] = "Zapisovanie testu";
$string['editingrandom'] = "Editova nhodn otzku";
$string['editingrandomsamatch'] = "Editova nhodn otzku s krtkou odpoveou";
$string['editingshortanswer'] = "Zapisovanie otzky s krtkou odpoveou";
$string['editingtruefalse'] = "Zapisovanie no/nie otzky";
$string['false'] = "Nesprvne";
$string['feedback'] = "Sptn vzba";
$string['fileformat'] = "Formt sboru";
$string['filloutoneanswer'] = "Muste vyplni aspo jednu mon odpove. Nevyplnen odpovede nebud pouit.";
$string['filloutthreequestions'] = "Muste vyplni aspo tri otzky. Nevyplnen otzky nebud pouit.";
$string['fillouttwochoices'] = "Muste uvies aspo dve monosti. Nevyplnen monosti nebud pouit.";
$string['fractionsaddwrong'] = "Kladn znmky, ktor ste uviedli nemaj set 100%%

<BR>ale ich set je \$a%%

<BR>Chcete s sp a opravi tto otzku?";
$string['fractionsnomax'] = "Jedna z odpoved mus by 100%%, aby bolo

<BR>mon zska pln poet za tto otzku.

<BR>Chcete s sp a opravi tto otzku?";
$string['gradeaverage'] = "Priemern znmka";
$string['gradehighest'] = "Najvyia znmka";
$string['grademethod'] = "Metda znmkovania";
$string['grades'] = "Znmky";
$string['guestsno'] = "Prepte, hostia  si nemu prezera alebo ska testy";
$string['imagedisplay'] = "Obraz na znzornenie";
$string['importquestions'] = "Import otzok zo sboru";
$string['introduction'] = "vod";
$string['marks'] = "Znmky";
$string['match'] = "Zodpovedajci";
$string['matchanswer'] = "Zodpovedajca odpove";
$string['missingcorrectanswer'] = "Muste oznai  sprvnu odpove";
$string['missingname'] = "Chba nzov otzky";
$string['missingquestiontext'] = "Chba text otzky";
$string['missingword'] = "Chba formt slova";
$string['modulename'] = "Test";
$string['modulenameplural'] = "Testy";
$string['multianswer'] = "S monosou vberu odpoved";
$string['multichoice'] = "Viacer monosti";
$string['noanswers'] = "Neboli vybrat iadne odpovede!";
$string['noattempts'] = "Nikto sa nepoksil urobi tento test";
$string['nomoreattempts'] = "Nie je povolen viac pokusov";
$string['noquestions'] = "Zatia neboli pridan otzky";
$string['noreview'] = "Nemte oprvnenie prehliada tento test";
$string['noreviewuntil'] = "Nemte oprvnenie prehliada tento test do \$a";
$string['notenoughsubquestions'] = "Nebolo definovan dos podotzok (monost).<br>

Chcete sa vrti a opravi tto otzku?";
$string['numerical'] = "Poradov";
$string['publish'] = "Publikova";
$string['qti'] = "Formt IMS QTI";
$string['question'] = "Otzka";
$string['questioninuse'] = "Otzka '\$a' je prve pouvan:";
$string['questionname'] = "Nzov otzky";
$string['questions'] = "Otzky";
$string['quizavailable'] = "Test je dostupn do: \$a";
$string['quizclose'] = "Zatvori test";
$string['quizclosed'] = "Tento test bol zatvoren \$a";
$string['quizcloses'] = "Test je uzatvoren";
$string['quiznotavailable'] = "Test nebude dostupn do: \$a";
$string['quizopen'] = "Otvori test";
$string['random'] = "Nhodn otzka";
$string['randomcreate'] = "Vytvori nhodn otzky";
$string['randomsamatch'] = "Nhodn zodpovedajca krtka odpove";
$string['randomsamatchcreate'] = "Vytvori nhodn zodpovedajce otzky s krtkymi odpoveami";
$string['randomsamatchintro'] = "Pre kad z nasledujcich otzok vyberte zodpovedajcu odpove z menu.";
$string['randomsamatchnumber'] = "Poet otzok, ktor chcete vybra";
$string['readytosend'] = "Pripravujete sa na posielanie celho vho testu na ohodnotenie. Ste si ist, e chcete pokraova?";
$string['recentlyaddedquestion'] = "Nedvno pridan otzka!";
$string['regrade'] = "Preznmkova vetky pokusy";
$string['regradecomplete'] = "Vetky pokusy boli preznmkovan";
$string['regradecount'] = "\$a->changed z \$a->attempt boli zmenen znmky";
$string['rename'] = "Premenova";
$string['report'] = "Zpisy";
$string['reportoverview'] = "Celkov prehad";
$string['reportregrade'] = "Preznmhova pokusy";
$string['reportsimplestat'] = "Jednoduch tatistika";
$string['review'] = "Prehad";
$string['save'] = "Uloi";
$string['savegrades'] = "Uloi znmky";
$string['savemyanswers'] = "Uloi moje odpovede";
$string['savequiz'] = "Uloi tento cel test";
$string['score'] = "Hrub skre";
$string['select'] = "Vybra";
$string['selectall'] = "Vybra vetko";
$string['selectcategoryabove'] = "Vybra kategriu z uvedench";
$string['shortanswer'] = "Krtka odpove";
$string['show'] = "Ukza";
$string['showcorrectanswer'] = "V sptnej vzbe zobrazi sprvne odpovede?";
$string['showfeedback'] = "Po zodpovedan ukte sptn vzbu?";
$string['shuffleanswers'] = "Zamiea otzky";
$string['shufflequestions'] = "Zamiea odpovede";
$string['time'] = "as";
$string['timecompleted'] = "as vypral";
$string['timetaken'] = "Strven as";
$string['toomanyrandom'] = "Poadovan poet nhodnch otzok je v, ne je obsiahnut v tejto kategrii! (\$a)";
$string['true'] = "Sprvne";
$string['truefalse'] = "Sprvne/Nesprvne";
$string['type'] = "Typ";
$string['viewallanswers'] = "Zobrazi \$a celch testov";
$string['viewallreports'] = "Prezrie zpisy \$a pokusov";
$string['webct'] = "Formt WebCT";
$string['yourfinalgradeis'] = "Vaa konen znmka za tento test je \$a";

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/sk/quiz.php <==
<?PHP // $Id$ Radik Kalakay - 2003-09-05 12:00 ver 1.1.a
      // quiz.php - created with Moodle 1.1 (2003082800)


$string['acceptederror'] = "Akceptovan chyba";
$string['addingquestions'] = "Toto je &#269;as&#357; strnky, kde si vediete databzu va&#353;ich otzok. Aby bolo otzky mo&#382;n udr&#382;a&#357; usporiadan a aby mohli by&#357; pou&#382;it v &#318;ubovo&#318;nom teste vo va&#353;om kurze, alebo dokonca aj inmi kurzami, ak sa rozhodnete publikova&#357; ich,s ulo&#382;en v kategrich.<br /><br />Ke&#271; vyberiete alebo vytvorte kategriu otzok, budete mc&#357; tvori&#357; alebo meni&#357; otzky. M&#382;ete vybra&#357; ktorko&#318;vek z tchto otzok a prida&#357; ju do v&#353;ho testu na ostatnch &#269;astiach tejto strnky.";
$string['addquestions'] = "Prida otzky";
$string['addquestionstoquiz'] = "Prida otzky do testu";
$string['addselectedtoquiz'] = "Vybran prida do testu";
$string['allowreview'] = "Povoli prehad";
$string['alreadysubmitted'] = "Je pravdepodobn e u ste predloili tento pokus";
$string['alwaysavailable'] = "Vdy dostupn";
$string['answer'] = "Odpove";
$string['answerhowmany'] = "Jedna, alebo viacero odpoved?";
$string['answersingleno'] = "Povolen viacero odpoved";
$string['answersingleyes'] = "Iba jedna odpove";
$string['answerswithacceptederrormarginmustbenumeric'] = "Odpovede s akceptovanmi chybami musia by slovan";
$string['attempt'] = "Pokus \$a";
$string['attemptfirst'] = "Prv pokus";
$string['attemptlast'] = "Posledn pokus";
$string['attemptquiznow'] = "Poksi sa urobi test teraz";
$string['attempts'] = "Pokusy";
$string['attemptsallowed'] = "Povolen poet pokusov";
$string['attemptsunlimited'] = "Neobmedzen pokusy";
$string['backtoquiz'] = "Sp na zapisovanie testu";
$string['bestgrade'] = "Najlepia znmka";
$string['blackboard'] = "ierna tabua";
$string['caseno'] = "Nie, vek a mal psmen nie s dleit";
$string['casesensitive'] = "Citlivos na vek a mal psmen";
$string['caseyes'] = "no, vek a mal psmen musia sedie";
$string['categories'] = "Kategrie";
$string['category'] = "Kategria";
$string['categoryinfo'] = "Informcie o kategrii";
$string['categorymove'] = "Kategria '\$a->name' obsahuje \$a->count otzok.  vyberte si prosm in kategriu, do ktorej ich prenesiete.";
$string['categorymoveto'] = "Preneste ich do tejto kategrie";
$string['choice'] = "Monos";
$string['choices'] = "Dostupn monosti";
$string['correctanswer'] = "Sprvna odpove";
$string['correctanswers'] = "Sprvne odpovede";
$string['countdown'] = "Odpotavanie";
$string['countdownfinished'] = "Test sa uzatvra, teraz moete zasiela svoje odpovede. ";
$string['countdowntenminutes'] = "Test sa uzavrie o 10 mint.";
$string['createmultiple'] = "Vytvori viacero otzok";
$string['createnewquestion'] = "Vytvori nov otzku";
$string['custom'] = "Uvatesk formt";
$string['daysavailable'] = "Dostupn dni";
$string['default'] = "Vchodiskov nastavenie";
$string['defaultgrade'] = "Prednastaven hodnota znmky";
$string['defaultinfo'] = "Nastaven kategria pre otzky.";
$string['deletequestioncheck'] = "Ste si plne ist, e chcete vymaza '\$a'?";
$string['description'] = "Opis";
$string['eachattemptbuildsonthelast'] = "Kad pokus je posaven na minulom";
$string['editcategories'] = "Upravi kategrie";
$string['editingdescription'] = "Upravi popis";
$string['editingmatch'] = "Editova zodpovedajcu otzku";
$string['editingmultianswer'] = "Upravi test s monosou vberu odpoved";
$string['editingmultichoice'] = "Zapisovanie otzky s viacermi monosami vberu";
$string['editingnumerical'] = "Upravi slovan otzky";
$string['editingquestion'] = "Zapisovanie otzky";
$string['editingquiz'] = "Zapisovanie testu";
$string['editingrandom'] = "Editova nhodn otzku";
$string['editingrandomsamatch'] = "Editova nhodn otzku s krtkou odpoveou";
$string['editingshortanswer'] = "Zapisovanie otzky s krtkou odpoveou";
$string['editingtruefalse'] = "Zapisovanie no/nie otzky";
$string['false'] = "Nesprvne";
$string['feedback'] = "Sptn vzba";
$string['fileformat'] = "Formt sboru";
$string['filloutoneanswer'] = "Muste vyplni aspo jednu mon odpove. Nevyplnen odpovede nebud pouit.";
$string['filloutthreequestions'] = "Muste vyplni aspo tri otzky. Nevyplnen otzky nebud pouit.";
$string['fillouttwochoices'] = "Muste uvies aspo dve monosti. Nevyplnen monosti nebud pouit.";
$string['fractionsaddwrong'] = "Kladn znmky, ktor ste uviedli nemaj set 100%%

<br />ale ich set je \$a%%

<br />Chcete s sp a opravi tto otzku?";
$string['fractionsnomax'] = "Jedna z odpoved mus by 100%%, aby bolo

<br />mon zska pln poet za tto otzku.

<br />Chcete s sp a opravi tto otzku?";
$string['gradeaverage'] = "Priemern znmka";
$string['gradehighest'] = "Najvyia znmka";
$string['grademethod'] = "Metda znmkovania";
$string['grades'] = "Znmky";
$string['guestsno'] = "Prepte, hostia  si nemu prezera alebo ska testy";
$string['imagedisplay'] = "Obraz na znzornenie";
$string['importquestions'] = "Import otzok zo sboru";
$string['introduction'] = "vod";
$string['marks'] = "Znmky";
$string['match'] = "Zodpovedajci";
$string['matchanswer'] = "Zodpovedajca odpove";
$string['missingcorrectanswer'] = "Muste oznai  sprvnu odpove";
$string['missingname'] = "Chba nzov otzky";
$string['missingquestiontext'] = "Chba text otzky";
$string['missingword'] = "Chba formt slova";
$string['modulename'] = "Test";
$string['modulenameplural'] = "Testy";
$string['multianswer'] = "S monosou vberu odpoved";
$string['multichoice'] = "Viacer monosti";
$string['noanswers'] = "Neboli vybrat iadne odpovede!";
$string['noattempts'] = "Nikto sa nepoksil urobi tento test";
$string['nomoreattempts'] = "Nie je povolen viac pokusov";
$string['noquestions'] = "Zatia neboli pridan otzky";
$string['noreview'] = "Nemte oprvnenie prehliada tento test";
$string['noreviewuntil'] = "Nemte oprvnenie prehliada tento test do \$a";
$string['notenoughsubquestions'] = "Nebolo definovan dos podotzok (monost).<br />

Chcete sa vrti a opravi tto otzku?";
$string['numerical'] = "Poradov";
$string['publish'] = "Publikova";
$string['qti'] = "Formt IMS QTI";
$string['question'] = "Otzka";
$string['questioninuse'] = "Otzka '\$a' je prve pouvan:";
$string['questionname'] = "Nzov otzky";
$string['questions'] = "Otzky";
$string['quizavailable'] = "Test je dostupn do: \$a";
$string['quizclose'] = "Zatvori test";
$string['quizclosed'] = "Tento test bol zatvoren \$a";
$string['quizcloses'] = "Test je uzatvoren";
$string['quiznotavailable'] = "Test nebude dostupn do: \$a";
$string['quizopen'] = "Otvori test";
$string['random'] = "Nhodn otzka";
$string['randomcreate'] = "Vytvori nhodn otzky";
$string['randomsamatch'] = "Nhodn zodpovedajca krtka odpove";
$string['randomsamatchcreate'] = "Vytvori nhodn zodpovedajce otzky s krtkymi odpoveami";
$string['randomsamatchintro'] = "Pre kad z nasledujcich otzok vyberte zodpovedajcu odpove z menu.";
$string['randomsamatchnumber'] = "Poet otzok, ktor chcete vybra";
$string['readytosend'] = "Pripravujete sa na posielanie celho vho testu na ohodnotenie. Ste si ist, e chcete pokraova?";
$string['recentlyaddedquestion'] = "Nedvno pridan otzka!";
$string['regrade'] = "Preznmkova vetky pokusy";
$string['regradecomplete'] = "Vetky pokusy boli preznmkovan";
$string['regradecount'] = "\$a->changed z \$a->attempt boli zmenen znmky";
$string['rename'] = "Premenova";
$string['report'] = "Zpisy";
$string['reportoverview'] = "Celkov prehad";
$string['reportregrade'] = "Preznmhova pokusy";
$string['reportsimplestat'] = "Jednoduch tatistika";
$string['review'] = "Prehad";
$string['save'] = "Uloi";
$string['savegrades'] = "Uloi znmky";
$string['savemyanswers'] = "Uloi moje odpovede";
$string['savequiz'] = "Uloi tento cel test";
$string['score'] = "Hrub skre";
$string['select'] = "Vybra";
$string['selectall'] = "Vybra vetko";
$string['selectcategoryabove'] = "Vybra kategriu z uvedench";
$string['shortanswer'] = "Krtka odpove";
$string['show'] = "Ukza";
$string['showcorrectanswer'] = "V sptnej vzbe zobrazi sprvne odpovede?";
$string['showfeedback'] = "Po zodpovedan ukte sptn vzbu?";
$string['shuffleanswers'] = "Zamiea otzky";
$string['shufflequestions'] = "Zamiea odpovede";
$string['time'] = "as";
$string['timecompleted'] = "as vypral";
$string['timetaken'] = "Strven as";
$string['toomanyrandom'] = "Poadovan poet nhodnch otzok je v, ne je obsiahnut v tejto kategrii! (\$a)";
$string['true'] = "Sprvne";
$string['truefalse'] = "Sprvne/Nesprvne";
$string['type'] = "Typ";
$string['viewallanswers'] = "Zobrazi \$a celch testov";
$string['viewallreports'] = "Prezrie zpisy \$a pokusov";
$string['webct'] = "Formt WebCT";
$string['yourfinalgradeis'] = "Vaa konen znmka za tento test je \$a";

?>
